==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/foundation/blockEntity/renderer/ColoredOverlayBlockEntityRenderer.java <==
package com.zurrtum.create.client.foundation.blockEntity.renderer;

import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import net.minecraft.class_11659;
import net.minecraft.class_11683;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public abstract class ColoredOverlayBlockEntityRenderer<T extends class_2586> implements class_827<T, ColoredOverlayBlockEntityRenderer.ColoredOverlayRenderState> {
    public ColoredOverlayBlockEntityRenderer(class_5614.class_5615 context) {
    }

    @Override
    public ColoredOverlayRenderState method_74335() {
        return new ColoredOverlayRenderState();
    }

    @Override
    public void updateRenderState(
        T be,
        ColoredOverlayRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_1921.method_23577();
        state.model = getOverlayBuffer(be, state);
        state.color = getColor(be, tickProgress);
    }

    @Override
    public void render(ColoredOverlayRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
    }

    protected abstract int getColor(T be, float partialTicks);

    protected abstract SuperByteBuffer getOverlayBuffer(T be, ColoredOverlayRenderState state);

    public static class ColoredOverlayRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public SuperByteBuffer model;
        public int color;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            model.color(color).light(field_62676).renderInto(matricesEntry, vertexConsumer);
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/foundation/blockEntity/renderer/ColoredOverlayBlockEntityRenderer.java <==
package com.zurrtum.create.client.foundation.blockEntity.renderer;

import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import net.minecraft.class_11659;
import net.minecraft.class_11683;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_12249;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public abstract class ColoredOverlayBlockEntityRenderer<T extends class_2586> implements class_827<T, ColoredOverlayBlockEntityRenderer.ColoredOverlayRenderState> {
    public ColoredOverlayBlockEntityRenderer(class_5614.class_5615 context) {
    }

    @Override
    public ColoredOverlayRenderState method_74335() {
        return new ColoredOverlayRenderState();
    }

    @Override
    public void extractRenderState(
        T be,
        ColoredOverlayRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_12249.method_75965();
        state.model = getOverlayBuffer(be, state);
        state.color = getColor(be, tickProgress);
    }

    @Override
    public void submit(ColoredOverlayRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
    }

    protected abstract int getColor(T be, float partialTicks);

    protected abstract SuperByteBuffer getOverlayBuffer(T be, ColoredOverlayRenderState state);

    public static class ColoredOverlayRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public SuperByteBuffer model;
        public int color;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            model.color(color).light(field_62676).renderInto(matricesEntry, vertexConsumer);
        }
    }
}
